==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/DEFERREDMAINTENANCEPARTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for DEFERREDMAINTENANCEPARTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="DEFERREDMAINTENANCEPARTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEFERREDMAINTENANCEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALLISTPARTLINENUM" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DEFERREDMAINTENANCEPARTID_Type", propOrder = {
    "deferredmaintenanceid",
    "materiallistpartlinenum"
})
public class DEFERREDMAINTENANCEPARTID_Type {

    @XmlElement(name = "DEFERREDMAINTENANCEID", required = true)
    protected DEFMID_Type deferredmaintenanceid;
    @XmlElement(name = "MATERIALLISTPARTLINENUM")
    protected Long materiallistpartlinenum;

    /**
     * Gets the value of the deferredmaintenanceid property.
     * 
     * @return
     *     possible object is
     *     {@link DEFMID_Type }
     *     
     */
    public DEFMID_Type getDEFERREDMAINTENANCEID() {
        return deferredmaintenanceid;
    }

    /**
     * Sets the value of the deferredmaintenanceid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEFMID_Type }
     *     
     */
    public void setDEFERREDMAINTENANCEID(DEFMID_Type value) {
        this.deferredmaintenanceid = value;
    }

    /**
     * Gets the value of the materiallistpartlinenum property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getMATERIALLISTPARTLINENUM() {
        return materiallistpartlinenum;
    }

    /**
     * Sets the value of the materiallistpartlinenum property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setMATERIALLISTPARTLINENUM(Long value) {
        this.materiallistpartlinenum = value;
    }

}

==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/DEFERREDMAINTENANCEPARTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour DEFERREDMAINTENANCEPARTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="DEFERREDMAINTENANCEPARTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEFERREDMAINTENANCEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALLISTPARTLINENUM" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DEFERREDMAINTENANCEPARTID_Type", propOrder = {
    "deferredmaintenanceid",
    "materiallistpartlinenum"
})
public class DEFERREDMAINTENANCEPARTID_Type {

    @XmlElement(name = "DEFERREDMAINTENANCEID", required = true)
    protected DEFMID_Type deferredmaintenanceid;
    @XmlElement(name = "MATERIALLISTPARTLINENUM")
    protected Long materiallistpartlinenum;

    /**
     * Obtient la valeur de la propriété deferredmaintenanceid.
     * 
     * @return
     *     possible object is
     *     {@link DEFMID_Type }
     *     
     */
    public DEFMID_Type getDEFERREDMAINTENANCEID() {
        return deferredmaintenanceid;
    }

    /**
     * Définit la valeur de la propriété deferredmaintenanceid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEFMID_Type }
     *     
     */
    public void setDEFERREDMAINTENANCEID(DEFMID_Type value) {
        this.deferredmaintenanceid = value;
    }

    /**
     * Obtient la valeur de la propriété materiallistpartlinenum.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getMATERIALLISTPARTLINENUM() {
        return materiallistpartlinenum;
    }

    /**
     * Définit la valeur de la propriété materiallistpartlinenum.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setMATERIALLISTPARTLINENUM(Long value) {
        this.materiallistpartlinenum = value;
    }

}
